==> piwigo_2.0.10.orig.tar.gz: piwigo-2.0.10/plugins/LocalFilesEditor/language/pl_PL/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Konfiguracja lokalna';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Szablony';
$lang['locfiledit_onglet_lang'] = 'Języki';
$lang['locfiledit_onglet_plug'] = 'Wtyczki własne';
$lang['locfiledit_cant_save'] = 'W pliku nie można zapisywać zmian. Sprawdź czy katalog "include/" jest zapisywalny (chmod).';
$lang['locfiledit_newfile'] = 'Plik nie istnieje i zostanie utworzony przez Edytora Plików Lokalnych';
$lang['locfiledit_save_config'] = 'Plik został zapisany pomyślnie.';
$lang['locfiledit_show_default'] = 'Pokaż plik referencyjny: ';
$lang['locfiledit_save_bak'] = 'Kopia zapasowa zostanie utworzona podczas zapisywania zmian.';
$lang['locfiledit_saved_bak'] = 'Plik kopii zapasowej utworzony (%s)';
$lang['locfiledit_save_file'] = 'Zapisz plik';
$lang['locfiledit_choose_file'] = 'Wybierz plik do edycji';
$lang['locfiledit_edit'] = 'Edytuj';
$lang['locfiledit_restore'] = 'Przywróć plik z kopii zapasowej';
$lang['locfiledit_restore_confirm'] = 'Potwierdź proszę?
Przywrócenie nie przyniesie efektu do następnego zapisu.';
$lang['locfiledit_bak_loaded1'] = 'Plik kopii zapasowej wczytany.';
$lang['locfiledit_bak_loaded2'] = 'Musisz zapisać plik aby go przywrócić.';
$lang['locfiledit_syntax_error'] = 'Błąd skłądni! Plik nie może zostać zapisany.';
$lang['locfiledit_enable_editarea'] = 'Włącz Pole Edycyjne';
$lang['locfiledit_disable_editarea'] = 'Wyłącz Pole Edycyjne';
$lang['locfiledit_new_tpl'] = 'Stwórz nowy plik';
$lang['locfiledit_new_filename'] = 'Nazwa pliku';
$lang['locfiledit_model'] = 'Model';
$lang['locfiledit_empty_page'] = 'Pusta strona';
$lang['locfiledit_parent_directory'] = 'Katalog nadrzędny';
$lang['locfiledit_filename_error'] = 'Plik zawiera niedozwolone znaki.';
$lang['locfiledit_file_already_exists'] = 'Plik już istnieje.';
$lang['locfiledit_model_error'] = 'Musisz wybrać model.';
$lang['locfiledit_empty_filename'] = 'Musisz wpisać nazwę pliku.';

?>

==> piwigo_2.1.2.orig.tar.gz: piwigo-2.1.2/plugins/LocalFilesEditor/language/pl_PL/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Konfiguracja lokalna';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Szablony';
$lang['locfiledit_onglet_lang'] = 'Języki';
$lang['locfiledit_onglet_plug'] = 'Wtyczki własne';
$lang['locfiledit_cant_save'] = 'W pliku nie można zapisywać zmian. Sprawdź czy katalog "include/" jest zapisywalny (chmod).';
$lang['locfiledit_newfile'] = 'Plik nie istnieje i zostanie utworzony przez Edytora Plików Lokalnych';
$lang['locfiledit_save_config'] = 'Plik został zapisany pomyślnie.';
$lang['locfiledit_show_default'] = 'Pokaż plik referencyjny: ';
$lang['locfiledit_save_bak'] = 'Kopia zapasowa zostanie utworzona podczas zapisywania zmian.';
$lang['locfiledit_saved_bak'] = 'Plik kopii zapasowej utworzony (%s)';
$lang['locfiledit_save_file'] = 'Zapisz plik';
$lang['locfiledit_choose_file'] = 'Wybierz plik do edycji';
$lang['locfiledit_edit'] = 'Edytuj';
$lang['locfiledit_restore'] = 'Przywróć plik z kopii zapasowej';
$lang['locfiledit_restore_confirm'] = 'Potwierdź proszę?
Przywrócenie nie przyniesie efektu do następnego zapisu.';
$lang['locfiledit_bak_loaded1'] = 'Plik kopii zapasowej wczytany.';
$lang['locfiledit_bak_loaded2'] = 'Musisz zapisać plik aby go przywrócić.';
$lang['locfiledit_syntax_error'] = 'Błąd skłądni! Plik nie może zostać zapisany.';
$lang['locfiledit_enable_editarea'] = 'Włącz Pole Edycyjne';
$lang['locfiledit_disable_editarea'] = 'Wyłącz Pole Edycyjne';
$lang['locfiledit_new_tpl'] = 'Stwórz nowy plik';
$lang['locfiledit_new_filename'] = 'Nazwa pliku';
$lang['locfiledit_model'] = 'Model';
$lang['locfiledit_empty_page'] = 'Pusta strona';
$lang['locfiledit_parent_directory'] = 'Katalog nadrzędny';
$lang['locfiledit_filename_error'] = 'Plik zawiera niedozwolone znaki.';
$lang['locfiledit_file_already_exists'] = 'Plik już istnieje.';
$lang['locfiledit_model_error'] = 'Musisz wybrać model.';
$lang['locfiledit_empty_filename'] = 'Musisz wpisać nazwę pliku.';
/* TODO */ $lang['locfiledit_webmaster_only'] = 'Only webmasters can create or modify local files.';

?>
